#!/bin/sh
echo 'name: hlint
version: 1.8.29
id: hlint-1.8.29-88b935989e5c4c54a30658d7cd0ccd27

license: GPL
copyright: Neil Mitchell 2006-2012
maintainer: Neil Mitchell <ndmitchell@gmail.com>
stability: Beta
homepage: http://community.haskell.org/~ndm/hlint/
package-url:
synopsis: Source code suggestions
description: HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
pkgpath: devel/hs-hlint
exposed: True
exposed-modules: Language.Haskell.HLint
hidden-modules: Paths_hlint Apply CmdLine HLint Idea Settings
                Report Test Util Parallel HSE.All HSE.Bracket HSE.Evaluate
                HSE.Match HSE.NameMatch HSE.Type HSE.Util Hint.All Hint.Bracket
                Hint.Duplicate Hint.Extensions Hint.Import Hint.Lambda Hint.List
                Hint.ListRec Hint.Match Hint.Monad Hint.Naming Hint.Pragma
                Hint.Structure Hint.Type Hint.Util
trusted: False
import-dirs: /usr/local/lib/ghc/hlint-1.8.29
library-dirs: /usr/local/lib/ghc/hlint-1.8.29
hs-libraries: HShlint-1.8.29
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         cpphs-1.13.3-22223ed30d0baa0d18c6553189e1cc46
         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
         haskell-src-exts-1.13.3-f45fa602e1b8c81a4df3ebfd09086435
         hscolour-1.19-0284a533d85963d0084c082e8de63eb3
         process-1.1.0.1-c55e7a2b0eb5149f070b14e14bea1c83
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
         uniplate-1.6.7-952017b8b36eba500d15313088618f3b
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hlint-1.8.29/html/hlint.haddock
haddock-html: /usr/local/share/doc/hs-hlint-1.8.29/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
